# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: rover.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'rover.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0brover.proto\x12\x05rover\"2\n\x0fVelocityCommand\x12\x0e\n\x06linear\x18\x01 \x01(\x02\x12\x0f\n\x07\x61ngular\x18\x02 \x01(\x02\"2\n\x13\x44ifferentialCommand\x12\x0c\n\x04left\x18\x01 \x01(\x02\x12\r\n\x05right\x18\x02 \x01(\x02\"Y\n\x0bGotoCommand\x12\x10\n\x08target_x\x18\x01 \x01(\x02\x12\x10\n\x08target_y\x18\x02 \x01(\x02\x12\x17\n\ntarget_yaw\x18\x03 \x01(\x02H\x00\x88\x01\x01\x42\r\n\x0b_target_yaw\"3\n\x07GotoAck\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x16\n\x0e\x65stimated_time\x18\x04 \x01(\x02\"\x8c\x01\n\x0cGotoProgress\x12\x10\n\x08progress\x18\x03 \x01(\x02\x12\x18\n\x10\x64istance_to_goal\x18\x04 \x01(\x02\x12\x15\n\rangle_to_goal\x18\x05 \x01(\x02\x12\x11\n\tcurrent_x\x18\x06 \x01(\x02\x12\x11\n\tcurrent_y\x18\x07 \x01(\x02\x12\x13\n\x0b\x63urrent_yaw\x18\x08 \x01(\x02\"[\n\x11RCChannelsCommand\x12\x10\n\x08\x63hannel1\x18\x01 \x01(\x05\x12\x10\n\x08\x63hannel2\x18\x02 \x01(\x05\x12\x10\n\x08\x63hannel3\x18\x03 \x01(\x05\x12\x10\n\x08\x63hannel4\x18\x04 \x01(\x05\"-\n\nLedCommand\x12\t\n\x01r\x18\x01 \x01(\r\x12\t\n\x01g\x18\x02 \x01(\r\x12\t\n\x01\x62\x18\x03 \x01(\r\"@\n\x10LedCustomCommand\x12\x0e\n\x06\x63olor1\x18\x01 \x03(\x05\x12\x0e\n\x06\x63olor2\x18\x02 \x03(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\x05\"E\n\rTelemetryData\x12\x10\n\x08position\x18\x01 \x03(\x02\x12\x10\n\x08velocity\x18\x02 \x03(\x02\x12\x10\n\x08\x61ttitude\x18\x03 \x03(\x02\"z\n\x0bRoverStatus\x12\x14\n\x0cis_connected\x18\x01 \x01(\x08\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x0e\n\x06uptime\x18\x04 \x01(\x03\x12\x18\n\x10\x66irmware_version\x18\x05 \x01(\t\x12\x0e\n\x06\x65rrors\x18\x06 \x03(\t\"2\n\x0b\x42\x61tteryData\x12\x0f\n\x07voltage\x18\x01 \x01(\x02\x12\x12\n\npercentage\x18\x02 \x01(\x05\"B\n\nCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x12\n\nerror_code\x18\x03 \x01(\t\"\x07\n\x05\x45mpty2\xdd\x07\n\x0cRoverService\x12\x39\n\x0cset_velocity\x12\x16.rover.VelocityCommand\x1a\x11.rover.CommandAck\x12G\n\x16set_differential_speed\x12\x1a.rover.DifferentialCommand\x1a\x11.rover.CommandAck\x12>\n\x0fset_rc_channels\x12\x18.rover.RCChannelsCommand\x1a\x11.rover.CommandAck\x12\x45\n\x12stream_rc_channels\x12\x18.rover.RCChannelsCommand\x1a\x11.rover.CommandAck(\x01\x30\x01\x12\'\n\x04stop\x12\x0c.rover.Empty\x1a\x11.rover.CommandAck\x12*\n\x04goto\x12\x12.rover.GotoCommand\x1a\x0e.rover.GotoAck\x12\x41\n\x14goto_stream_position\x12\x12.rover.GotoCommand\x1a\x13.rover.GotoProgress0\x01\x12.\n\x0bgoto_cancel\x12\x0c.rover.Empty\x1a\x11.rover.CommandAck\x12\x30\n\x0bgoto_status\x12\x0c.rover.Empty\x1a\x13.rover.GotoProgress\x12\x33\n\x0bled_control\x12\x11.rover.LedCommand\x1a\x11.rover.CommandAck\x12\x38\n\nled_custom\x12\x17.rover.LedCustomCommand\x1a\x11.rover.CommandAck\x12\'\n\x04\x62\x65\x65p\x12\x0c.rover.Empty\x1a\x11.rover.CommandAck\x12&\n\x03moo\x12\x0c.rover.Empty\x1a\x11.rover.CommandAck\x12\x33\n\rget_telemetry\x12\x0c.rover.Empty\x1a\x14.rover.TelemetryData\x12\x38\n\x10stream_telemetry\x12\x0c.rover.Empty\x1a\x14.rover.TelemetryData0\x01\x12.\n\nget_status\x12\x0c.rover.Empty\x1a\x12.rover.RoverStatus\x12\x36\n\x12get_battery_status\x12\x0c.rover.Empty\x1a\x12.rover.BatteryData\x12\x31\n\x0e\x65mergency_stop\x12\x0c.rover.Empty\x1a\x11.rover.CommandAckb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rover_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_VELOCITYCOMMAND']._serialized_start=22
  _globals['_VELOCITYCOMMAND']._serialized_end=72
  _globals['_DIFFERENTIALCOMMAND']._serialized_start=74
  _globals['_DIFFERENTIALCOMMAND']._serialized_end=124
  _globals['_GOTOCOMMAND']._serialized_start=126
  _globals['_GOTOCOMMAND']._serialized_end=215
  _globals['_GOTOACK']._serialized_start=217
  _globals['_GOTOACK']._serialized_end=268
  _globals['_GOTOPROGRESS']._serialized_start=271
  _globals['_GOTOPROGRESS']._serialized_end=411
  _globals['_RCCHANNELSCOMMAND']._serialized_start=413
  _globals['_RCCHANNELSCOMMAND']._serialized_end=504
  _globals['_LEDCOMMAND']._serialized_start=506
  _globals['_LEDCOMMAND']._serialized_end=551
  _globals['_LEDCUSTOMCOMMAND']._serialized_start=553
  _globals['_LEDCUSTOMCOMMAND']._serialized_end=617
  _globals['_TELEMETRYDATA']._serialized_start=619
  _globals['_TELEMETRYDATA']._serialized_end=688
  _globals['_ROVERSTATUS']._serialized_start=690
  _globals['_ROVERSTATUS']._serialized_end=812
  _globals['_BATTERYDATA']._serialized_start=814
  _globals['_BATTERYDATA']._serialized_end=864
  _globals['_COMMANDACK']._serialized_start=866
  _globals['_COMMANDACK']._serialized_end=932
  _globals['_EMPTY']._serialized_start=934
  _globals['_EMPTY']._serialized_end=941
  _globals['_ROVERSERVICE']._serialized_start=944
  _globals['_ROVERSERVICE']._serialized_end=1933
# @@protoc_insertion_point(module_scope)
